@@ -62,7 +62,6 @@ class GradeNotebooks():
             raise e  
         return "Grading Done"
 
-
 class GoogleOAuth2LoginHandler(tornado.web.RequestHandler,
                                tornado.auth.GoogleOAuth2Mixin):
     async def get(self):
@@ -102,9 +101,8 @@ class Userform(BaseHandler, tornado.web.RequestHandler):
         log.write_logs("6.", "Authenticated!", "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
         self.render("index.html",  message=None)
 
-            
-
-class Download(tornado.web.RequestHandler):
+class Download(BaseHandler, tornado.web.RequestHandler):
+    @tornado.web.authenticated
     async def post(self):
         code = self.get_argument('download')
         directory = f"{__UPLOADS__}/{code}"
@@ -137,7 +135,8 @@ class Download(tornado.web.RequestHandler):
                 except Exception as exc:
                     self.write(exc)
 
-class Upload(tornado.web.RequestHandler):    
+class Upload(BaseHandler,tornado.web.RequestHandler):    
+    @tornado.web.authenticated
     async def post(self):
         g = GradeNotebooks()
         files = self.request.files
